================
Tomato Commander
================


.. image:: https://img.shields.io/pypi/v/tomato_commander.svg
        :target: https://pypi.python.org/pypi/tomato_commander

.. image:: https://img.shields.io/travis/voglster/tomato_commander.svg
        :target: https://travis-ci.org/voglster/tomato_commander

.. image:: https://readthedocs.org/projects/tomato-commander/badge/?version=latest
        :target: https://tomato-commander.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status

.. image:: https://pyup.io/repos/github/voglster/tomato_commander/shield.svg
     :target: https://pyup.io/repos/github/voglster/tomato_commander/
     :alt: Updates


Simple library for controlling static leases on a tomato router.


* Free software: GNU General Public License v3
* Documentation: https://tomato-commander.readthedocs.io.


Features
--------

* TODO

Credits
---------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage

